require 'bundler/setup'
require 'pg'
require 'test/unit'
require 'seeding_utils'

connection = nil
SeedingUtils.connect -> {
  connection ||= PG::Connection.open dbname: 'test_seeding_utils'
}


class SeedingUtilsTest < Test::Unit::TestCase

  def setup
    @conn = SeedingUtils.connection
    @conn.exec <<-END
      SET client_min_messages TO 'warning';
      DROP TABLE IF EXISTS people;
      CREATE TABLE people (
        id INTEGER PRIMARY KEY,
        name VARCHAR(255) NOT NULL
      );
      INSERT INTO people (id, name) VALUES (1, 'John Doe');
      INSERT INTO people (id, name) VALUES (2, 'Juan Fulano');
    END
  end

  def test_should_dump_copy_data
    table = SeedingUtils::Table.new 'people'
    io = StringIO.new('', 'r+:binary')
    assert_equal 0, io.size
    table.dump(io)
    assert io.size > 0
    data = io.read.force_encoding 'BINARY'
    assert_match 'Juan Fulano', data
  end

  def test_should_read_copy_data
    table = SeedingUtils::Table.new 'people'
    io = StringIO.new('', 'r+:binary')
    table.dump(io)
    @conn.exec 'DELETE FROM people'
    result = @conn.exec 'SELECT COUNT(*) FROM people'
    assert_equal "0", result.getvalue(0, 0)
    table.load(io)
    result = @conn.exec 'SELECT COUNT(*) FROM people'
    assert_equal "2", result.getvalue(0, 0)
  end
end
